@@ -5,6 +5,9 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+/*  #include <limits.h> */
+
+/*  #define PATH_MAX 4 */
 
 #include "support.h"
 #include "perspic.h"
@@ -336,6 +339,7 @@ on_save_as_1_activate                  (GtkMenuItem     *menuitem,
 
 }
 
+static char name_buf[PATH_MAX];
 
 void
 on_print1_activate                     (GtkMenuItem     *menuitem,
@@ -350,7 +354,12 @@ on_print1_activate                     (GtkMenuItem     *menuitem,
   char *c;
 
   home=getenv("HOME");
-  s=tempnam(home,NULL);
+/*    s=tempnam(home,NULL); */
+  if (snprintf(name_buf,sizeof(name_buf),"%s/perspic_print",home)<=0) {
+    err("Cannot write temp filename for printing\n");
+    return;
+  }
+  s=name_buf;
   if (!map_open(&m,s,1)) {
     err("Can't open %s\n",s);
     return;
@@ -393,8 +402,6 @@ on_print1_activate                     (GtkMenuItem     *menuitem,
     return;
   }
 
-    
-
 }
 
 
@@ -470,7 +477,6 @@ on_font3_activate                      (GtkMenuItem     *menuitem,
 
 }
 
-
 void
 on_preview1_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -486,7 +492,12 @@ on_preview1_activate                   (GtkMenuItem     *menuitem,
     err("HOME environment variable unset\n");
     return;
   }
-  s=tempnam(home,NULL);
+/*    s=tempnam(home,NULL); */
+  if (snprintf(name_buf,sizeof(name_buf),"%s/perspic_preview",home)<=0) {
+    err("Cannot write temp filename for previewing\n");
+    return;
+  }
+  s=name_buf;
   if (!map_open(&m,s,1)) {
     err("Can't open %s\n",s);
     return;
